Projection
==========

.. container:: subclasses
    *Subclasses*

    .. toctree::
       :maxdepth: 1

       PathwayProjection
       ModulatoryProjection

.. automodule:: psyneulink.core.components.projections.projection
   :members:
   :private-members:
   :exclude-members: _is_projection_spec, random, Parameters, ProjectionError, DuplicateProjectionError
